==> ideaIC-141.1192.2-sources.jar: org/jetbrains/jps/intellilang/instrumentation/ErrorPostponingMethodVisitor.java <==
/*
 * Copyright 2000-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.jps.intellilang.instrumentation;

import com.intellij.compiler.instrumentation.FailSafeMethodVisitor;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.org.objectweb.asm.MethodVisitor;
import org.jetbrains.org.objectweb.asm.Opcodes;

/**
 * @author Eugene Zhuravlev
 *         Date: 11/5/13
 */
public class ErrorPostponingMethodVisitor extends FailSafeMethodVisitor {

  private final PatternInstrumenter myInstrumenter;
  private final String myMethodName;

  public ErrorPostponingMethodVisitor(@NotNull PatternInstrumenter instrumenter, String methodName, @Nullable MethodVisitor methodvisitor) {
    super(Opcodes.ASM5, methodvisitor);
    myInstrumenter = instrumenter;
    myMethodName = methodName;
  }

  public void visitMaxs(int maxStack, int maxLocals) {
    try {
      super.visitMaxs(maxStack, maxLocals);
    }
    catch (Throwable e) {
      myInstrumenter.registerError(myMethodName, "visitMaxs", e);
    }
  }
}

==> ideaIC-173.3531.6-sources.jar: org/jetbrains/jps/intellilang/instrumentation/ErrorPostponingMethodVisitor.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.jps.intellilang.instrumentation;

import com.intellij.compiler.instrumentation.FailSafeMethodVisitor;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.org.objectweb.asm.MethodVisitor;
import org.jetbrains.org.objectweb.asm.Opcodes;

/**
 * @author Eugene Zhuravlev
 *         Date: 11/5/13
 */
public class ErrorPostponingMethodVisitor extends FailSafeMethodVisitor {

  private final PatternInstrumenter myInstrumenter;
  private final String myMethodName;

  public ErrorPostponingMethodVisitor(@NotNull PatternInstrumenter instrumenter, String methodName, @Nullable MethodVisitor methodvisitor) {
    super(Opcodes.API_VERSION, methodvisitor);
    myInstrumenter = instrumenter;
    myMethodName = methodName;
  }

  public void visitMaxs(int maxStack, int maxLocals) {
    try {
      super.visitMaxs(maxStack, maxLocals);
    }
    catch (Throwable e) {
      myInstrumenter.registerError(myMethodName, "visitMaxs", e);
    }
  }
}
